Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk::PNG - PNG loader for Tk::Photo

SYNOPSIS

use Tk;
use Tk::PNG;

my $image = $widget->Photo('-format' => 'png', -file => 'something.png');

DESCRIPTION

This is an extension for Tk which supplies PNG format loader for Photo image type.

HISTORY

This extension is by default bundled with Perl/Tk since Tk804.

AUTHOR

Nick Ing-Simmons <nick@ing-simmons.net>

SEE ALSO

Tk::Photo.