Security Advisories (3)
CVE-2007-4769 (2008-01-09)

The regular expression parser in TCL before 8.4.17, as used in PostgreSQL 8.2 before 8.2.6, 8.1 before 8.1.11, 8.0 before 8.0.15, and 7.4 before 7.4.19, allows remote authenticated users to cause a denial of service (backend crash) via an out-of-bounds backref number.

CVE-2018-25032 (2022-03-25)

zlib before 1.2.12 allows memory corruption when deflating (i.e., when compressing) if the input has many distant matches.

CVE-2011-3045 (2012-03-22)

Integer signedness error in the png_inflate function in pngrutil.c in libpng before 1.4.10beta01, as used in Google Chrome before 17.0.963.83 and other products, allows remote attackers to cause a denial of service (application crash) or possibly execute arbitrary code via a crafted PNG file, a different vulnerability than CVE-2011-3026.

NAME

Tk::Tiler - Scrollable frame with sub-widgets arranged into rows

SYNOPSIS

use Tk::Tiler;

my $tl = $parent->Scrolled('Tiler', -columns => n, -rows => n);

my $a  = $tl->Xxxxx(...);
my $b  = $tl->Xxxxx(...);
my $c  = $tl->Xxxxx(...);

$tl->Manage($a,$b,$c);

DESCRIPTION

Tiler is derived form Tk::Frame. It is a geometry managing widget which accepts widgets to manage. It places the widgets in a grid with as many widgets as possible in a row. All the "slots" in the grid are the same size, which is determined by the largest managed widget.

The grid may be scrolled vertically.